import React from 'react';
import ReactDOM from 'react-dom';
import { arc } from 'd3';

const width = window.innerWidth;
const height = window.innerHeight;
const centerX = width / 2;
const centerY = height / 2;
const strokeWidth = 20;

const eyeOffsetX = 90;
const eyeOffsetY = -130;
const glassRadius = 95;
const glassBracket = 15;

const mouthRadius = 175;
const tongueRadius = 100;
const tongueOffset = 190;

const glassArc = arc()
  .innerRadius(0)
  .outerRadius(glassRadius)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

const mouthArc = arc()
  .innerRadius(0)
  .outerRadius(mouthRadius)
  .startAngle(Math.PI / 2)
  .endAngle((Math.PI * 3) / 2);

const tongueArc = arc()
  .innerRadius(0)
  .outerRadius(tongueRadius)
  .startAngle(-Math.PI / 2)
  .endAngle(Math.PI / 2);

const Glasses = () => (
  <>
    <rect
      transform={`translate(${
        -centerY + strokeWidth
      },${eyeOffsetY})`}
      width={`${(centerY - strokeWidth) * 2}`}
      height={`${glassBracket}`}
    />
    <path
      transform={`translate(${-eyeOffsetX},${eyeOffsetY})`}
      d={glassArc()}
    />
    <g
      transform={`translate(${-eyeOffsetX},${
        eyeOffsetY + glassBracket
      }) scale(0.7 0.65)`}
    >
      <path d={glassArc()} fill="#222" />
    </g>

    <path
      transform={`translate(${eyeOffsetX},${eyeOffsetY})`}
      d={glassArc()}
    />
    <g
      transform={`translate(${eyeOffsetX},${
        eyeOffsetY + glassBracket
      }) scale(0.7 0.65)`}
    >
      <path d={glassArc()} fill="#222" />
    </g>
  </>
);

const Mouth = () => (
  <g>
    <g>
      <clipPath id="mouth">
        <path d={mouthArc()} />
      </clipPath>
      <path fill="#891946" d={mouthArc()} />
    </g>
    <g clip-path="url(#mouth)">
      <path
        transform={`translate(0,${tongueOffset})`}
        fill="#f6c0d8"
        d={tongueArc()}
      />
    </g>
  </g>
);

const App = () => (
  <svg width={width} height={height}>
    <g transform={`translate(${centerX},${centerY})`}>
      <circle
        r={centerY - strokeWidth / 2}
        fill="#fbe056"
        stroke="black"
        stroke-width={strokeWidth}
      />
      <Glasses />
      <Mouth />
    </g>
  </svg>
);

const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
